==> react-native-web-jsonschema-form-2.0.5.tgz: package/widgets/ScheduleWidget/index.js <==
import _times from "lodash/times";
import _get from "lodash/get";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import { StyleSheet } from 'react-native';
import Screen from 'react-native-web-ui-components/Screen';
import { days } from '../../utils';
import fillSchedule from './fillSchedule';
import ArrayWidget from '../ArrayWidget';
import CheckAll from './CheckAll';
const styles = StyleSheet.create({
  dateContainer: {
    minWidth: 130,
    maxWidth: 130,
    width: 130,
    marginRight: 10
  },
  timesContainer: {
    minWidth: 250,
    flex: 1
  },
  checkbox: {
    height: 40,
    marginBottom: 10
  },
  checkboxXs: {
    height: 23,
    marginBottom: 5
  }
});

const alwaysTrue = () => true;

const getProps = props => {
  const {
    schema,
    value,
    uiSchema
  } = props;
  const attributes = Object.keys(schema.items.properties);

  if (attributes.length > 2) {
    throw new Error('Schedule widget is supposed to run on an array with day/date and time');
  }

  const index = schema.items.properties[attributes[0]].type === 'array' ? 0 : 1;
  const timesAttribute = attributes[index];
  const dateAttribute = attributes[index ? 0 : 1];

  const dateWidget = _get(uiSchema, ['items', dateAttribute, 'ui:widget'], 'checkbox');

  const checkbox = dateWidget === 'checkbox';
  let propertySchema = schema;
  let adjustedValue = value;

  if (checkbox) {
    adjustedValue = fillSchedule(adjustedValue, timesAttribute, dateAttribute);
    propertySchema = {
      type: 'array',
      items: {
        type: 'object',
        properties: {
          [dateAttribute]: {
            type: 'boolean'
          },
          [timesAttribute]: {
            type: 'string'
          }
        }
      }
    };
  }

  const filterTime = _get(uiSchema, ['items', timesAttribute, 'ui:widgetProps', 'filterTime'], alwaysTrue);

  const propertyUiSchema = {
    'ui:title': false,
    'ui:options': {
      addable: false,
      removable: false
    },
    ...uiSchema,
    items: {
      'ui:title': false,
      'ui:grid': [{
        type: 'row',
        xs: 12,
        children: [dateAttribute, timesAttribute]
      }],
      [dateAttribute]: { ..._get(uiSchema, ['items', dateAttribute], {}),
        'ui:title': false,
        'ui:widget': dateWidget,
        'ui:widgetProps': dateWidget === 'checkbox' ? days.map((text, i) => ({ ..._get(uiSchema, ['items', dateAttribute, 'ui:widgetProps'], {}),
          text,
          adjustTitle: false,
          style: [Screen.getType() === 'xs' ? styles.checkboxXs : styles.checkbox, i === 0 ? {
            marginTop: Screen.getType() !== 'xs' ? 4 : 0
          } : null, i === 0 && Screen.getType() === 'xs' ? {
            marginBottom: 9
          } : null]
        })) : _get(uiSchema, ['items', dateAttribute, 'ui:widgetProps'], {})
      },
      [timesAttribute]: { ..._get(uiSchema, ['items', timesAttribute], {}),
        'ui:title': false,
        'ui:widget': 'timeRange',
        'ui:widgetProps': _times(7, i => ({ ..._get(uiSchema, ['items', timesAttribute, 'ui:widgetProps'], {}),
          encoder: 'string',
          header: i === 0,
          disabled: checkbox && !adjustedValue[i][dateAttribute],
          filterTime: time => filterTime(time, _get(value, i, {}))
        })),
        'ui:containerProps': {
          style: styles.timesContainer
        }
      }
    }
  };

  const container = _get(uiSchema, ['items', dateAttribute, 'ui:containerProps'], {});

  propertyUiSchema.items[dateAttribute]['ui:containerProps'] = { ...container
  };
  propertyUiSchema.items[dateAttribute]['ui:containerProps'].style = [styles.dateContainer, container.style || null];

  if (!checkbox) {
    const widgetProps = propertyUiSchema.items[dateAttribute]['ui:widgetProps'];
    propertyUiSchema.items[dateAttribute]['ui:widgetProps'] = [{ ...widgetProps,
      style: [{
        marginTop: Screen.getType() !== 'xs' ? 4 : 0
      }, widgetProps.style || null]
    }, widgetProps];
  }

  const options = { ...(propertyUiSchema['ui:options'] || {})
  };
  options.orderable = false;

  if (checkbox) {
    options.addable = false;
    options.removable = false;
  }

  propertyUiSchema['ui:options'] = options;
  return { ...props,
    checkbox,
    dateAttribute,
    timesAttribute,
    propertyUiSchema,
    propertySchema,
    value: adjustedValue
  };
};

const useCheckboxParser = ({
  dateAttribute,
  timesAttribute
}) => value => value.map((v, i) => ({
  on: v[dateAttribute],
  day: days[i],
  times: v[timesAttribute]
})).filter(v => v.on).map(v => ({
  [dateAttribute]: v.day,
  [timesAttribute]: v.times
}));

const useDateParser = () => value => value;

const useOnChange = ({
  name,
  value,
  onChange,
  scheduleParser,
  dateAttribute,
  timesAttribute
}) => (propertyValue, propertyName, params = {}) => {
  if (propertyName !== name) {
    const path = propertyName.split('.');
    const [key] = path.splice(-1, 1);
    const index = parseInt(path.splice(-1, 1)[0], 10);

    while (value.length <= index) {
      value.push({
        [dateAttribute]: null,
        [timesAttribute]: ''
      });
    }

    value[index][key] = propertyValue; // eslint-disable-line

    onChange(scheduleParser(value), name, { ...params,
      update: [`${name}.${index}.${dateAttribute}`, `${name}.${index}.${timesAttribute}`]
    });
  } else {
    const update = [];
    const length = Math.max(propertyValue.length, value.length);

    for (let i = 0; i < length; i += 1) {
      update.push(`${name}.${i}.${dateAttribute}`);
      update.push(`${name}.${i}.${timesAttribute}`);
    }

    onChange(propertyValue, propertyName, { ...params,
      update
    });
  }
};

const ScheduleWidget = props => {
  const params = getProps(props);
  const dateParser = useDateParser(params);
  const checkboxParser = useCheckboxParser(params);
  const {
    checkbox,
    propertySchema,
    propertyUiSchema
  } = params;
  const scheduleParser = checkbox ? checkboxParser : dateParser;
  const onChange = useOnChange({ ...params,
    scheduleParser
  });
  return React.createElement(React.Fragment, null, React.createElement(CheckAll, _extends({}, params, {
    onChange: onChange,
    scheduleParser: scheduleParser,
    propertyUiSchema: propertyUiSchema
  })), React.createElement(ArrayWidget, _extends({}, params, {
    onChange: onChange,
    schema: propertySchema,
    uiSchema: propertyUiSchema
  })));
};

export default ScheduleWidget;

==> react-native-web-jsonschema-form-2.0.15.tgz: package/widgets/ScheduleWidget/index.js <==
import _times from "lodash/times";
import _get from "lodash/get";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import { StyleSheet } from 'react-native';
import Screen from 'react-native-web-ui-components/Screen';
import Row from 'react-native-web-ui-components/Row';
import { days } from '../../utils';
import fillSchedule from './fillSchedule';
import ArrayWidget from '../ArrayWidget';
import CheckAll from './CheckAll';
const styles = StyleSheet.create({
  dateContainer: {
    minWidth: 130,
    maxWidth: 130,
    width: 130,
    marginRight: 10
  },
  timesContainer: {
    minWidth: 250,
    flex: 1
  },
  checkbox: {
    height: 40,
    marginBottom: 10
  },
  checkboxXs: {
    height: 23,
    marginBottom: 5
  },
  titlePadding: {
    paddingTop: 10
  }
});

const alwaysTrue = () => true;

const getProps = props => {
  const {
    schema,
    value,
    uiSchema
  } = props;
  const attributes = Object.keys(schema.items.properties);

  if (attributes.length > 2) {
    throw new Error('Schedule widget is supposed to run on an array with day/date and time');
  }

  const index = schema.items.properties[attributes[0]].type === 'array' ? 0 : 1;
  const timesAttribute = attributes[index];
  const dateAttribute = attributes[index ? 0 : 1];

  const dateWidget = _get(uiSchema, ['items', dateAttribute, 'ui:widget'], 'checkbox');

  const checkbox = dateWidget === 'checkbox';
  let propertySchema = schema;
  let adjustedValue = value;

  if (checkbox) {
    adjustedValue = fillSchedule(adjustedValue, timesAttribute, dateAttribute);
    propertySchema = {
      type: 'array',
      items: {
        type: 'object',
        properties: {
          [dateAttribute]: {
            type: 'boolean'
          },
          [timesAttribute]: {
            type: 'string'
          }
        }
      }
    };
  }

  const filterTime = _get(uiSchema, ['items', timesAttribute, 'ui:widgetProps', 'filterTime'], alwaysTrue);

  const propertyUiSchema = {
    'ui:options': {
      addable: false,
      removable: false
    },
    ...uiSchema,
    'ui:title': false,
    items: {
      'ui:title': false,
      'ui:grid': [{
        type: 'row',
        xs: 12,
        children: [dateAttribute, timesAttribute]
      }],
      [dateAttribute]: { ..._get(uiSchema, ['items', dateAttribute], {}),
        'ui:title': false,
        'ui:widget': dateWidget,
        'ui:widgetProps': dateWidget === 'checkbox' ? days.map((text, i) => ({ ..._get(uiSchema, ['items', dateAttribute, 'ui:widgetProps'], {}),
          text,
          adjustTitle: false,
          style: [Screen.getType() === 'xs' ? styles.checkboxXs : styles.checkbox, i === 0 ? {
            marginTop: Screen.getType() !== 'xs' ? 4 : 0
          } : null, i === 0 && Screen.getType() === 'xs' ? {
            marginBottom: 9
          } : null]
        })) : _get(uiSchema, ['items', dateAttribute, 'ui:widgetProps'], {})
      },
      [timesAttribute]: { ..._get(uiSchema, ['items', timesAttribute], {}),
        'ui:title': false,
        'ui:widget': 'timeRange',
        'ui:widgetProps': _times(7, i => ({ ..._get(uiSchema, ['items', timesAttribute, 'ui:widgetProps'], {}),
          encoder: 'string',
          header: i === 0,
          disabled: checkbox && !adjustedValue[i][dateAttribute],
          filterTime: time => filterTime(time, _get(value, i, {}))
        })),
        'ui:containerProps': {
          style: styles.timesContainer
        }
      }
    }
  };

  const container = _get(uiSchema, ['items', dateAttribute, 'ui:containerProps'], {});

  propertyUiSchema.items[dateAttribute]['ui:containerProps'] = { ...container
  };
  propertyUiSchema.items[dateAttribute]['ui:containerProps'].style = [styles.dateContainer, container.style || null];

  if (!checkbox) {
    const widgetProps = propertyUiSchema.items[dateAttribute]['ui:widgetProps'];
    propertyUiSchema.items[dateAttribute]['ui:widgetProps'] = [{ ...widgetProps,
      style: [{
        marginTop: Screen.getType() !== 'xs' ? 4 : 0
      }, widgetProps.style || null]
    }, widgetProps];
  }

  const options = { ...(propertyUiSchema['ui:options'] || {})
  };
  options.orderable = false;

  if (checkbox) {
    options.addable = false;
    options.removable = false;
  }

  propertyUiSchema['ui:options'] = options;
  return { ...props,
    checkbox,
    dateAttribute,
    timesAttribute,
    propertyUiSchema,
    propertySchema,
    value: adjustedValue
  };
};

const useCheckboxParser = ({
  dateAttribute,
  timesAttribute
}) => value => value.map((v, i) => ({
  on: v[dateAttribute],
  day: days[i],
  times: v[timesAttribute]
})).filter(v => v.on).map(v => ({
  [dateAttribute]: v.day,
  [timesAttribute]: v.times
}));

const useDateParser = () => value => value;

const useOnChange = ({
  name,
  value,
  onChange,
  scheduleParser,
  dateAttribute,
  timesAttribute
}) => (propertyValue, propertyName, params = {}) => {
  if (propertyName !== name) {
    const path = propertyName.split('.');
    const [key] = path.splice(-1, 1);
    const index = parseInt(path.splice(-1, 1)[0], 10);

    while (value.length <= index) {
      value.push({
        [dateAttribute]: null,
        [timesAttribute]: ''
      });
    }

    value[index][key] = propertyValue; // eslint-disable-line

    onChange(scheduleParser(value), name, { ...params,
      update: [`${name}.${index}.${dateAttribute}`, `${name}.${index}.${timesAttribute}`]
    });
  } else {
    const update = [];
    const length = Math.max(propertyValue.length, value.length);

    for (let i = 0; i < length; i += 1) {
      update.push(`${name}.${i}.${dateAttribute}`);
      update.push(`${name}.${i}.${timesAttribute}`);
    }

    onChange(propertyValue, propertyName, { ...params,
      update
    });
  }
};

const ScheduleWidget = props => {
  const params = getProps(props);
  const dateParser = useDateParser(params);
  const checkboxParser = useCheckboxParser(params);
  const {
    checkbox,
    propertySchema,
    propertyUiSchema
  } = params;
  const scheduleParser = checkbox ? checkboxParser : dateParser;
  const onChange = useOnChange({ ...params,
    scheduleParser
  });
  const hasTitle = params.uiSchema['ui:title'] !== false;
  return React.createElement(Row, {
    style: hasTitle ? styles.titlePadding : null
  }, React.createElement(CheckAll, _extends({}, params, {
    onChange: onChange,
    scheduleParser: scheduleParser,
    propertyUiSchema: propertyUiSchema
  })), React.createElement(ArrayWidget, _extends({}, params, {
    onChange: onChange,
    schema: propertySchema,
    uiSchema: propertyUiSchema
  })));
};

export default ScheduleWidget;
